@@ -1137,3 +1137,179 @@ class TestUnit(unittest.TestCase):
         self.assertEqual(post_dst.dtype, np.dtype('datetime64[D]'))
         self.assertEqual([str(dt) for dt in post_dst],
             ['2022-01-01', '2022-01-01', '2022-01-01', '1999-09-09', '1743-09-01', '1743-09-01', '1999-09-09', '2005-11-01'])
+
+    #---------------------------------------------------------------------------
+
+    def test_tri_map_merge_a(self) -> None:
+        src = np.array([0, 200, 300, 400, 0], dtype=np.int64)
+        dst = np.array([300, 400, 0, 200, 300], dtype=np.int64)
+
+        tm = TriMap(len(src), len(dst))
+        tm.register_one(0, 2)
+        tm.register_one(1, 3)
+        tm.register_many(2, np.array([0, 4], dtype=np.dtype(np.int64)))
+        tm.register_one(3, 1)
+        tm.register_one(4, 2)
+
+        with self.assertRaises(RuntimeError):
+            _ = tm.map_merge(src, dst)
+
+        tm.finalize()
+
+        with self.assertRaises(TypeError):
+            _ = tm.map_merge(3, dst)
+
+        with self.assertRaises(TypeError):
+            _ = tm.map_merge(src, 3)
+
+        with self.assertRaises(TypeError):
+            _ = tm.map_merge(src.reshape(5, 1), dst)
+
+        with self.assertRaises(TypeError):
+            _ = tm.map_merge(src, dst.reshape(5, 1))
+
+
+    def test_tri_map_merge_a(self) -> None:
+        src = np.array([0, 200, 300, 400, 0], dtype=np.int64)
+        dst = np.array([300, 400, 0, 200, 300, 50, 50], dtype=np.int64)
+
+        tm = TriMap(len(src), len(dst))
+        tm.register_one(0, 2)
+        tm.register_one(1, 3)
+        tm.register_many(2, np.array([0, 4], dtype=np.dtype(np.int64)))
+        tm.register_one(3, 1)
+        tm.register_one(4, 2)
+        tm.register_unmatched_dst()
+        tm.finalize()
+
+        post = tm.map_merge(src, dst)
+        self.assertEqual(post.tolist(), [0, 200, 300, 300, 400, 0, 50, 50])
+
+    def test_tri_map_merge_b(self) -> None:
+        src = np.array([0, 200, 300, 400], dtype=np.int64)
+        dst = np.array([50, 80, 200, 300, 0, 200, 300, 70, 80], dtype=np.int32)
+
+        tm = TriMap(len(src), len(dst))
+        tm.register_one(0, 4)
+        tm.register_many(1, np.array([2, 5], dtype=np.dtype(np.int64)))
+        tm.register_many(2, np.array([3, 6], dtype=np.dtype(np.int64)))
+        tm.register_one(3, -1)
+        tm.register_unmatched_dst()
+        tm.finalize()
+
+        post = tm.map_merge(src, dst)
+        self.assertEqual(post.tolist(), [0, 200, 200, 300, 300, 400, 50, 80, 70, 80])
+
+    def test_tri_map_merge_c(self) -> None:
+        src = np.array([0, 200, 300, 400], dtype=np.int64)
+        dst = np.array([400, 200, 300], dtype=np.int64)
+
+        tm = TriMap(len(src), len(dst))
+        tm.register_one(0, -1)
+        tm.register_one(1, 1)
+        tm.register_one(2, 2)
+        tm.register_one(3, 0)
+        tm.register_unmatched_dst()
+        tm.finalize()
+
+        post = tm.map_merge(src, dst)
+        self.assertEqual(post.tolist(), [0, 200, 300, 400])
+
+    def test_tri_map_merge_d(self) -> None:
+        src = np.array(['a', 'bbb', 'cc', 'dddd'])
+        dst = np.array(['cc', 'a', 'a', 'ee', 'cc'])
+
+        tm = TriMap(len(src), len(dst))
+        tm.register_many(0, np.array([1, 2], dtype=np.dtype(np.int64)))
+        tm.register_one(1, -1)
+        tm.register_many(2, np.array([0, 4], dtype=np.dtype(np.int64)))
+        tm.register_one(3, -1)
+        tm.register_unmatched_dst()
+        tm.finalize()
+
+        post = tm.map_merge(src, dst)
+        self.assertEqual(post.tolist(), ['a', 'a', 'bbb', 'cc', 'cc', 'dddd', 'ee'])
+
+
+
+    def test_tri_map_merge_e(self) -> None:
+        src = np.array([None, False, -42, 'dddd'], dtype=object)
+        dst = np.array([-42, None, None, 'ee', -42], dtype=object)
+
+        tm = TriMap(len(src), len(dst))
+        tm.register_many(0, np.array([1, 2], dtype=np.dtype(np.int64)))
+        tm.register_one(1, -1)
+        tm.register_many(2, np.array([0, 4], dtype=np.dtype(np.int64)))
+        tm.register_one(3, -1)
+        tm.register_unmatched_dst()
+        tm.finalize()
+
+        post = tm.map_merge(src, dst)
+        self.assertEqual(post.tolist(), [None, None, False, -42, -42, 'dddd', 'ee'])
+
+    def test_tri_map_merge_f(self) -> None:
+        src = np.array([None, False, -42,], dtype=object)
+        dst = np.array([True, 'ee', 88], dtype=object)
+
+        tm = TriMap(len(src), len(dst))
+        tm.register_one(0, -1)
+        tm.register_one(1, -1)
+        tm.register_one(2, -1)
+        tm.register_unmatched_dst()
+        tm.finalize()
+
+        post = tm.map_merge(src, dst)
+        self.assertEqual(post.tolist(), [None, False, -42, True, 'ee', 88])
+
+    def test_tri_map_merge_g(self) -> None:
+        src = np.array([None, False, -42,], dtype=object)
+        dst = np.array([None, False, -42, 'ee', 'ff'], dtype=object)
+
+        tm = TriMap(len(src), len(dst))
+        tm.register_one(0, 0)
+        tm.register_one(1, 1)
+        tm.register_one(2, 2)
+        tm.register_unmatched_dst()
+        tm.finalize()
+
+        post = tm.map_merge(src, dst)
+        self.assertEqual(post.tolist(), [None, False, -42, 'ee', 'ff'])
+
+    def test_tri_map_merge_h(self) -> None:
+        src = np.array([0, 200, 300, 40], dtype=np.int64)
+        dst = np.array([0, 200, 300, 40, 50], dtype=np.int64)
+
+        tm = TriMap(len(src), len(dst))
+        tm.register_one(0, 0)
+        tm.register_one(1, 1)
+        tm.register_one(2, 2)
+        tm.register_one(3, 3)
+        tm.register_unmatched_dst()
+        tm.finalize()
+
+        post = tm.map_merge(src, dst)
+        self.assertEqual(post.tolist(), [0, 200, 300, 40, 50])
+
+    def test_tri_map_merge_i(self) -> None:
+        src = np.array(['2022-01', '1954-03', '1743-09', '1988-12'], dtype=np.datetime64)
+        dst = np.array(['1743-09', '2022-01', '2022-01', '2022-01', '1743-09', '2005-11'], dtype=np.datetime64)
+
+        tm = TriMap(len(src), len(dst))
+        tm.register_many(0, np.array([1, 2, 3], dtype=np.dtype(np.int64)))
+        tm.register_one(1, -1)
+        tm.register_many(2, np.array([0, 4], dtype=np.dtype(np.int64)))
+        tm.register_one(3, -1)
+        tm.register_unmatched_dst()
+        tm.finalize()
+
+        post = tm.map_merge(src, dst)
+        self.assertEqual(list(post),
+            [np.datetime64('2022-01'),
+             np.datetime64('2022-01'),
+             np.datetime64('2022-01'),
+             np.datetime64('1954-03'),
+             np.datetime64('1743-09'),
+             np.datetime64('1743-09'),
+             np.datetime64('1988-12'),
+             np.datetime64('2005-11')]
+             )
